@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@ if (!empty($data['hostid'])) {
 // Create form.
 $triggersForm = (new CForm())
 	->setName('triggersForm')
+	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('form', $data['form'])
 	->addVar('hostid', $data['hostid'])
 	->addVar('expression_constructor', $data['expression_constructor'])
@@ -56,11 +57,8 @@ if ($readonly) {
 	$triggersForm
 		->addVar('recovery_mode', $data['recovery_mode'])
 		->addVar('type', $data['type'])
-		->addVar('correlation_mode', $data['correlation_mode']);
-
-	if ($data['config']['event_ack_enable']) {
-		$triggersForm->addVar('manual_close', $data['manual_close']);
-	}
+		->addVar('correlation_mode', $data['correlation_mode'])
+		->addVar('manual_close', $data['manual_close']);
 }
 
 // Create form list.
@@ -75,9 +73,11 @@ if ($discovered_trigger) {
 	));
 }
 
-$triggersFormList->addRow(_('Name'),
+$triggersFormList->addRow(
+	(new CLabel(_('Name'), 'description'))->setAsteriskMark(),
 	(new CTextBox('description', $data['description'], $readonly))
 		->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		->setAriaRequired()
 		->setAttribute('autofocus', 'autofocus')
 );
 
@@ -100,26 +100,34 @@ if ($data['recovery_expression_field_readonly']) {
 	$triggersForm->addVar('recovery_expression', $data['recovery_expression']);
 }
 
+$popup_options = [
+	'srctbl' => $data['expression_field_name'],
+	'srcfld1' => $data['expression_field_name'],
+	'dstfrm' => $triggersForm->getName(),
+	'dstfld1' => $data['expression_field_name']
+];
+
+if ($data['groupid'] && $data['hostid']) {
+	$popup_options['groupid'] = $data['groupid'];
+	$popup_options['hostid'] = $data['hostid'];
+}
+
 $expression_row = [
 	(new CTextArea(
 		$data['expression_field_name'],
 		$data['expression_field_value'],
 		['readonly' => $data['expression_field_readonly']]
-	))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
+	))
+		->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		->setAriaRequired(),
 	(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 	(new CButton('insert', ($data['expression_constructor'] == IM_TREE) ? _('Edit') : _('Add')))
 		->addClass(ZBX_STYLE_BTN_GREY)
-		->onClick(
-			'return PopUp("popup_trexpr.php?dstfrm='.$triggersForm->getName().
-				'&dstfld1='.$data['expression_field_name'].'&srctbl='.$data['expression_field_name'].
-				'&srcfld1='.$data['expression_field_name'].
-				(($data['groupid'] && $data['hostid'])
-					? '&groupid='.$data['groupid'].'&hostid='.$data['hostid']
-					: ''
-				).
-				'&expression="+encodeURIComponent(jQuery(\'[name="'.$data['expression_field_name'].'"]\').val()));'
+		->onClick('return PopUp("popup.triggerexpr",jQuery.extend('.CJs::encodeJson($popup_options).
+			',{expression: jQuery(\'[name="'.$data['expression_field_name'].'"]\').val()}), null, this);'
 		)
 		->setEnabled(!$readonly)
+		->removeId()
 ];
 
 if ($data['expression_constructor'] == IM_TREE) {
@@ -171,13 +179,16 @@ elseif ($data['expression_constructor'] != IM_FORCED) {
 	$expression_row[] = [BR(), $input_method_toggle];
 }
 
-$triggersFormList->addRow(_('Expression'), $expression_row, 'expression_row');
+$triggersFormList->addRow(
+	(new CLabel(_('Expression'), $data['expression_field_name']))->setAsteriskMark(),
+	$expression_row,
+	'expression_row'
+);
 
 // Append expression table to form list.
 if ($data['expression_constructor'] == IM_TREE) {
 	$expressionTable = (new CTable())
 		->setAttribute('style', 'width: 100%;')
-		->setId('exp_list')
 		->setHeader([
 			$readonly ? null : _('Target'),
 			_('Expression'),
@@ -209,10 +220,8 @@ if ($data['expression_constructor'] == IM_TREE) {
 			if ($readonly) {
 				// Make all links inside inactive.
 				foreach ($e['list'] as &$obj) {
-					if (gettype($obj) === 'object' && get_class($obj) === 'CSpan'
-							&& $obj->getAttribute('class') == ZBX_STYLE_LINK_ACTION) {
-						$obj->removeAttribute('class');
-						$obj->onClick(null);
+					if ($obj instanceof CLinkAction && $obj->getAttribute('class') == ZBX_STYLE_LINK_ACTION) {
+						$obj = new CSpan($obj->items);
 					}
 				}
 				unset($obj);
@@ -224,6 +233,7 @@ if ($data['expression_constructor'] == IM_TREE) {
 						? (new CCheckBox('expr_target_single', $e['id']))
 							->setChecked($i == 0)
 							->onClick('check_target(this, '.TRIGGER_EXPRESSION.');')
+							->removeId()
 						: null,
 					$e['list'],
 					!$readonly
@@ -249,11 +259,10 @@ if ($data['expression_constructor'] == IM_TREE) {
 	}
 
 	$testButton = (new CButton('test_expression', _('Test')))
-		->onClick('openWinCentered("tr_testexpr.php?expression="+'.
-			'encodeURIComponent(this.form.elements["expression"].value),'.
-			'"ExpressionTest", 950, 650, "titlebar=no, resizable=yes, scrollbars=yes"); return false;'
-		)
-		->addClass(ZBX_STYLE_BTN_LINK);
+		->onClick('return PopUp("popup.testtriggerexpr",{expression: this.form.elements["expression"].value}, null,'.
+					'this);')
+		->addClass(ZBX_STYLE_BTN_LINK)
+		->removeId();
 
 	if (!$allowed_testing) {
 		$testButton->setEnabled(false);
@@ -291,27 +300,34 @@ $triggersFormList->addRow(_('OK event generation'),
 		->setEnabled(!$readonly)
 );
 
+$popup_options = [
+	'srctbl' => $data['recovery_expression_field_name'],
+	'srcfld1' => $data['recovery_expression_field_name'],
+	'dstfrm' => $triggersForm->getName(),
+	'dstfld1' => $data['recovery_expression_field_name']
+];
+if ($data['groupid'] && $data['hostid']) {
+	$popup_options['groupid'] = $data['groupid'];
+	$popup_options['hostid'] = $data['hostid'];
+}
+
 $recovery_expression_row = [
 	(new CTextArea(
 		$data['recovery_expression_field_name'],
 		$data['recovery_expression_field_value'],
 		['readonly' => $data['recovery_expression_field_readonly']]
-	))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
+	))
+		->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		->setAriaRequired(),
 	(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 	(new CButton('insert', ($data['recovery_expression_constructor'] == IM_TREE) ? _('Edit') : _('Add')))
 		->addClass(ZBX_STYLE_BTN_GREY)
-		->onClick(
-			'return PopUp("popup_trexpr.php?dstfrm='.$triggersForm->getName().
-				'&dstfld1='.$data['recovery_expression_field_name'].
-				'&srctbl='.$data['recovery_expression_field_name'].'&srcfld1='.$data['recovery_expression_field_name'].
-				(($data['groupid'] && $data['hostid'])
-					? '&groupid='.$data['groupid'].'&hostid='.$data['hostid']
-					: ''
-				).
-				'&expression="+encodeURIComponent(jQuery(\'[name="'.$data['recovery_expression_field_name'].
-				'"]\').val()));'
+		->onClick('return PopUp("popup.triggerexpr",jQuery.extend('.
+			CJs::encodeJson($popup_options).
+				',{expression: jQuery(\'[name="'.$data['recovery_expression_field_name'].'"]\').val()}), null, this);'
 		)
 		->setEnabled(!$readonly)
+		->removeId()
 ];
 
 if ($data['recovery_expression_constructor'] == IM_TREE) {
@@ -358,7 +374,10 @@ elseif ($data['recovery_expression_constructor'] != IM_FORCED) {
 	$recovery_expression_row[] = [BR(), $input_method_toggle];
 }
 
-$triggersFormList->addRow(_('Recovery expression'), $recovery_expression_row, null,
+$triggersFormList->addRow(
+	(new CLabel(_('Recovery expression'), $data['recovery_expression_field_name']))->setAsteriskMark(),
+	$recovery_expression_row,
+	null,
 	'recovery_expression_constructor_row'
 );
 
@@ -366,7 +385,6 @@ $triggersFormList->addRow(_('Recovery expression'), $recovery_expression_row, nu
 if ($data['recovery_expression_constructor'] == IM_TREE) {
 	$recovery_expression_table = (new CTable())
 		->setAttribute('style', 'width: 100%;')
-		->setId('exp_list')
 		->setHeader([
 			$readonly ? null : _('Target'),
 			_('Expression'),
@@ -399,10 +417,8 @@ if ($data['recovery_expression_constructor'] == IM_TREE) {
 			if ($readonly) {
 				// Make all links inside inactive.
 				foreach ($e['list'] as &$obj) {
-					if (gettype($obj) === 'object' && get_class($obj) === 'CSpan'
-							&& $obj->getAttribute('class') == ZBX_STYLE_LINK_ACTION) {
-						$obj->removeAttribute('class');
-						$obj->onClick(null);
+					if ($obj instanceof CLinkAction && $obj->getAttribute('class') == ZBX_STYLE_LINK_ACTION) {
+						$obj = new CSpan($obj->items);
 					}
 				}
 				unset($obj);
@@ -414,6 +430,7 @@ if ($data['recovery_expression_constructor'] == IM_TREE) {
 						? (new CCheckBox('recovery_expr_target_single', $e['id']))
 							->setChecked($i == 0)
 							->onClick('check_target(this, '.TRIGGER_RECOVERY_EXPRESSION.');')
+							->removeId()
 						: null,
 					$e['list'],
 					!$readonly
@@ -439,11 +456,10 @@ if ($data['recovery_expression_constructor'] == IM_TREE) {
 	}
 
 	$testButton = (new CButton('test_expression', _('Test')))
-		->onClick('openWinCentered("tr_testexpr.php?expression="'.
-			'+encodeURIComponent(this.form.elements["recovery_expression"].value),'.
-			'"ExpressionTest", 950, 650, "titlebar=no, resizable=yes, scrollbars=yes"); return false;'
-		)
-		->addClass(ZBX_STYLE_BTN_LINK);
+		->onClick('return PopUp("popup.testtriggerexpr",'.
+			'{expression: this.form.elements["recovery_expression"].value}, null, this);')
+		->addClass(ZBX_STYLE_BTN_LINK)
+		->removeId();
 
 	if (!$allowed_testing) {
 		$testButton->setAttribute('disabled', 'disabled');
@@ -489,9 +505,11 @@ $triggersFormList
 			->setEnabled(!$readonly),
 		'correlation_mode_row'
 	)
-	->addRow(_('Tag for matching'),
+	->addRow(
+		(new CLabel(_('Tag for matching'), 'correlation_tag'))->setAsteriskMark(),
 		(new CTextBox('correlation_tag', $data['correlation_tag'], $readonly))
-			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+			->setAriaRequired(),
 		'correlation_tag_row'
 	);
 
@@ -533,13 +551,11 @@ $triggersFormList->addRow(_('Tags'),
 		->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;')
 );
 
-if ($data['config']['event_ack_enable']) {
-	$triggersFormList->addRow(_('Allow manual close'),
-		(new CCheckBox('manual_close'))
-			->setChecked($data['manual_close'] == ZBX_TRIGGER_MANUAL_CLOSE_ALLOWED)
-			->setEnabled(!$readonly)
-	);
-}
+$triggersFormList->addRow(_('Allow manual close'),
+	(new CCheckBox('manual_close'))
+		->setChecked($data['manual_close'] == ZBX_TRIGGER_MANUAL_CLOSE_ALLOWED)
+		->setEnabled(!$readonly)
+);
 
 // Append status to form list.
 if (empty($data['triggerid']) && empty($data['form_refresh'])) {
@@ -590,6 +606,7 @@ foreach ($data['db_dependencies'] as $dependency) {
 					: (new CButton('remove', _('Remove')))
 						->onClick('javascript: removeDependency("'.$dependency['triggerid'].'");')
 						->addClass(ZBX_STYLE_BTN_LINK)
+						->removeId()
 			))->addClass(ZBX_STYLE_NOWRAP)
 		]))->setId('dependency_'.$dependency['triggerid'])
 	);
@@ -601,8 +618,17 @@ $dependenciesFormList->addRow(_('Dependencies'),
 		$discovered_trigger
 			? null
 			: (new CButton('bnt1', _('Add')))
-				->onClick('return PopUp("popup.php?srctbl=triggers&srcfld1=triggerid&reference=deptrigger'.
-					'&multiselect=1&with_triggers=1&noempty=1");'
+				->onClick('return PopUp("popup.generic",'.
+					CJs::encodeJson([
+						'srctbl' => 'triggers',
+						'srcfld1' => 'triggerid',
+						'reference' => 'deptrigger',
+						'hostid' => $data['hostid'],
+						'groupid' => $data['groupid'],
+						'multiselect' => '1',
+						'with_triggers' => '1',
+						'noempty' => '1'
+					]).', null, this);'
 				)
 				->addClass(ZBX_STYLE_BTN_LINK)
 	]))
