@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2017 Zabbix SIA
+ ** Copyright (C) 2001-2019 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -20,8 +20,20 @@
 
 jQuery(function($) {
 
-	if ($('#search').length) {
+	var $search = $('#search');
+
+	if ($search.length) {
 		createSuggest('search');
+
+		$search.keyup(function() {
+			$search
+				.siblings('button')
+				.attr('disabled', ($.trim($search.val()) === '') ? true : null);
+		}).closest('form').submit(function() {
+			if ($.trim($search.val()) === '') {
+				return false;
+			}
+		});
 	}
 
 	if (IE) {
@@ -49,52 +61,95 @@ jQuery(function($) {
 		changeClass(comboBox);
 	});
 
-	/**
-	 * Build menu popup for given elements.
-	 */
-	$(document).on('click', '[data-menu-popup]', function(event) {
-		var obj = $(this),
-			data = obj.data('menu-popup');
-
+	function showMenuPopup(obj, data, event) {
 		switch (data.type) {
 			case 'history':
 				data = getMenuPopupHistory(data);
 				break;
 
 			case 'host':
-				data = getMenuPopupHost(data);
+				data = getMenuPopupHost(data, obj);
 				break;
 
-			case 'map':
-				data = getMenuPopupMap(data);
+			case 'map_element_submap':
+				data = getMenuPopupMapElementSubmap(data);
+				break;
+
+			case 'map_element_group':
+				data = getMenuPopupMapElementGroup(data);
+				break;
+
+			case 'map_element_trigger':
+				data = getMenuPopupMapElementTrigger(data);
+				break;
+
+			case 'map_element_image':
+				data = getMenuPopupMapElementImage(data);
 				break;
 
 			case 'refresh':
-				data = getMenuPopupRefresh(data);
+				data = getMenuPopupRefresh(data, obj);
 				break;
 
 			case 'trigger':
-				data = getMenuPopupTrigger(data);
+				data = getMenuPopupTrigger(data, obj);
 				break;
 
-			case 'triggerLog':
-				data = getMenuPopupTriggerLog(data);
-				break;
-
-			case 'triggerMacro':
+			case 'trigger_macro':
 				data = getMenuPopupTriggerMacro(data);
 				break;
 
-			case 'dependent_items':
-				data = getMenuPopupDependentItems(data);
+			case 'dashboard':
+				data = getMenuPopupDashboard(data, obj);
 				break;
 
-			case 'dashboard':
-				data = getMenuPopupDashboard(data);
+			case 'item':
+				data = getMenuPopupItem(data, obj);
+				break;
+
+			case 'item_prototype':
+				data = getMenuPopupItemPrototype(data);
 				break;
 		}
 
 		obj.menuPopup(data, event);
+	}
+
+	/**
+	 * Build menu popup for given elements.
+	 */
+	$(document).on('keydown click', '[data-menu-popup]', function(event) {
+		var obj = $(this),
+			data = obj.data('menu-popup');
+
+		if (event.type === 'keydown') {
+			if (event.which != 13) {
+				return;
+			}
+
+			event.preventDefault();
+			event.target = this;
+		}
+
+		var	url = new Curl('zabbix.php'),
+			ajax_data = {
+				data: data.data
+			};
+
+		url.setArgument('action', 'menu.popup');
+		url.setArgument('type', data.type);
+
+		$.ajax({
+			url: url.getUrl(),
+			method: 'POST',
+			data: ajax_data,
+			dataType: 'json',
+			success: function(resp) {
+				showMenuPopup(obj, resp.data, event);
+			},
+			error: function() {
+			}
+		});
 
 		return false;
 	});
@@ -120,20 +175,44 @@ jQuery(function($) {
 						'name': data.values[i].name
 					};
 
-					if (typeof(data.values[i].prefix) !== 'undefined') {
+					if (typeof data.values[i].prefix !== 'undefined') {
 						item.prefix = data.values[i].prefix;
 					}
 
-					jQuery('#' + data.parentId).multiSelect('addData', item);
+					$('#' + data.parentId).multiSelect('addData', item);
 				}
 			}
 		}
+		else if ($('[name="'+data.parentId+'"]').hasClass('patternselect')) {
+			/**
+			 * Pattern select allows to enter multiple comma or newline separated values in same editable field. Values
+			 * passed to add.popup should be appended at the end of existing value string.
+			 *
+			 * values_arr is used to catch duplicates.
+			 * values_str is used to store user's original syntax.
+			 */
+			var values_str = $('[name="'+data.parentId+'"]').val(),
+				values_arr = values_str.split(/[,|\n]+/).map(function(str) {return str.trim()});
+
+			data.values.forEach(function(val) {
+				if (values_arr.indexOf(val[data.object]) == -1) {
+					if (values_str !== '') {
+						values_str += ', ';
+					}
+					values_str += val[data.object];
+				}
+			});
+
+			$('[name="'+data.parentId+'"]')
+				.val(values_str)
+				.trigger('change');
+		}
 		else if (typeof addPopupValues !== 'undefined') {
 			// execute function if they exist
 			addPopupValues(data);
 		}
 		else {
-			jQuery('#' + data.parentId).val(data.values[0].name);
+			$('#' + data.parentId).val(data.values[0].name);
 		}
 	});
 
@@ -145,5 +224,8 @@ jQuery(function($) {
 		if (typeof confirmation === 'undefined' || (typeof confirmation !== 'undefined' && confirm(confirmation))) {
 			window.location = button.data('url');
 		}
-	})
+	});
+
+	// Initialize hintBox event handlers.
+	hintBox.bindEvents();
 });
